@@ -24,43 +24,9 @@ use chrono;
 
 use chrono::Local;
 use iotdb_client_rs::client::remote::{Config, RpcSession};
-use iotdb_client_rs::client::{DataSet, MeasurementSchema, Session, Tablet, Value};
+use iotdb_client_rs::client::{MeasurementSchema, RowRecord, Session, Tablet, Value};
 use iotdb_client_rs::protocal::{TSCompressionType, TSDataType, TSEncoding};
-use prettytable::{cell, Cell, Row, Table};
-
-fn print_dataset(dataset: Box<dyn DataSet>) -> Result<(), Box<dyn Error>> {
-    let mut table = Table::new();
-
-    let mut title_cells: Vec<Cell> = Vec::new();
-
-    let is_ignore_timestamp = dataset.is_ignore_timestamp();
-    if !is_ignore_timestamp {
-        title_cells.push(cell!("Time"));
-    }
-
-    dataset
-        .get_column_names()
-        .iter()
-        .for_each(|name| title_cells.push(cell!(name)));
-
-    table.set_titles(Row::new(title_cells));
-
-    dataset.for_each(|record| {
-        let mut row_cells: Vec<Cell> = Vec::new();
-        if !is_ignore_timestamp {
-            row_cells.push(cell!(record.timestamp.to_string()));
-        }
-
-        record
-            .values
-            .iter()
-            .for_each(|v| row_cells.push(cell!(v.to_string())));
-
-        table.add_row(Row::new(row_cells));
-    });
-    table.printstd();
-    Ok(())
-}
+use prettytable::{cell, Row, Table};
 
 fn main() -> Result<(), Box<dyn Error>> {
     let config = Config {
@@ -72,17 +38,7 @@ fn main() -> Result<(), Box<dyn Error>> {
     };
 
     //rpc session
-    let session = RpcSession::new(&config)?;
-    run_example(session)?;
-
-    //Local filesystem session
-    // let session = DirectSession::new("/data/apache-iotdb-0.12.3-server-bin");
-    // run_example(session)?;
-
-    Ok(())
-}
-
-fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
+    let mut session = RpcSession::new(&config)?;
     session.open()?;
 
     let tz = session.get_time_zone()?;
@@ -99,7 +55,7 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
 
     //create_timeseries
     session.create_timeseries(
-        "root.sg1.dev2.status",
+        "root.sg_rs.dev2.status",
         TSDataType::Float,
         TSEncoding::Plain,
         TSCompressionType::SNAPPY,
@@ -108,21 +64,21 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
         None,
         None,
     )?;
-    session.delete_timeseries(vec!["root.sg1.dev2.status"])?;
+    session.delete_timeseries(vec!["root.sg_rs.dev2.status"])?;
 
     //insert_record
     session.insert_record(
-        "root.sg1.dev5",
+        "root.sg_rs.dev5",
         vec!["online", "desc"],
         vec![Value::Bool(false), Value::Text("F4145".to_string())],
         Local::now().timestamp_millis(),
         false,
     )?;
-    session.delete_timeseries(vec!["root.sg1.dev5.online", "root.sg1.dev5.desc"])?;
+    session.delete_timeseries(vec!["root.sg_rs.dev5.online", "root.sg_rs.dev5.desc"])?;
 
     //insert_records
     session.insert_records(
-        vec!["root.sg1.dev1"],
+        vec!["root.sg_rs.dev1"],
         vec![vec![
             "restart_count",
             "tick_count",
@@ -142,12 +98,12 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
         vec![Local::now().timestamp_millis()],
     )?;
     session.delete_timeseries(vec![
-        "root.sg1.dev1.restart_count",
-        "root.sg1.dev1.tick_count",
-        "root.sg1.dev1.price",
-        "root.sg1.dev1.temperature",
-        "root.sg1.dev1.description",
-        "root.sg1.dev1.status",
+        "root.sg_rs.dev1.restart_count",
+        "root.sg_rs.dev1.tick_count",
+        "root.sg_rs.dev1.price",
+        "root.sg_rs.dev1.temperature",
+        "root.sg_rs.dev1.description",
+        "root.sg_rs.dev1.status",
     ])?;
 
     //create_multi_timeseries
@@ -165,20 +121,23 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
 
     //delete_timeseries
     session.insert_string_record(
-        "root.ln.wf02.wt02",
+        "root.sg_rs.wf02.wt02",
         vec!["id", "location"],
         vec!["SN:001", "BeiJing"],
         Local::now().timestamp_millis(),
         false,
     )?;
-    session.delete_timeseries(vec!["root.ln.wf02.wt02.id", "root.ln.wf02.wt02.location"])?;
+    session.delete_timeseries(vec![
+        "root.sg_rs.wf02.wt02.id",
+        "root.sg_rs.wf02.wt02.location",
+    ])?;
 
     //insert_records_of_one_device
     session.insert_records_of_one_device(
-        "root.sg1.dev0",
+        "root.sg_rs.dev0",
         vec![
             Local::now().timestamp_millis(),
-            Local::now().timestamp_millis() + 1,
+            Local::now().timestamp_millis() - 1,
         ],
         vec![
             vec!["restart_count", "tick_count", "price"],
@@ -187,8 +146,8 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
         vec![
             vec![Value::Int32(1), Value::Int64(2018), Value::Double(1988.1)],
             vec![
-                Value::Float(12.1),
-                Value::Text("Test Device 1".to_string()),
+                Value::Float(36.8),
+                Value::Text("thermograph".to_string()),
                 Value::Bool(false),
             ],
         ],
@@ -198,55 +157,128 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
     //tablet
     let mut ts = Local::now().timestamp_millis();
 
-    let tablet1 = create_tablet(5, ts);
+    let mut tablet1 = create_tablet(5, ts);
+    tablet1.sort();
     ts += 5;
 
-    let tablet2 = create_tablet(10, ts);
+    let mut tablet2 = create_tablet(10, ts);
     ts += 10;
 
-    let tablet3 = create_tablet(2, ts);
+    let mut tablet3 = create_tablet(2, ts);
 
-    session.insert_tablet(&tablet1, true)?;
-    session.insert_tablets(vec![&tablet2, &tablet3], true)?;
+    tablet1.sort();
+    session.insert_tablet(&tablet1)?;
+
+    tablet2.sort();
+    tablet3.sort();
+    session.insert_tablets(vec![&tablet2, &tablet3])?;
 
     //delete_data
     session.insert_records_of_one_device(
-        "root.sg1.dev1",
+        "root.sg_rs.dev1",
         vec![1, 16],
         vec![vec!["status"], vec!["status"]],
         vec![vec![Value::Bool(true)], vec![Value::Bool(true)]],
         true,
     )?;
-    session.delete_data(vec!["root.sg1.dev1.status"], 1, 16)?;
+    session.delete_data(vec!["root.sg_rs.dev1.status"], 1, 16)?;
+
+    let dataset = session.execute_query_statement("select * from root.sg_rs.device2", None)?;
+
+    // Get columns, column types and values from the data set
+    // For example:
+    // dataset
+    //     .get_column_names()
+    //     .iter()
+    //     .for_each(|c| print!("{}\t", c));
+    // print!("\n");
+    // dataset
+    //     .get_data_types()
+    //     .iter()
+    //     .for_each(|c| print!("{:?}\t", c));
+    // print!("\n");
+    // dataset.for_each(|r| {
+    //     r.values.iter().for_each(|v| match v {
+    //         Value::Bool(v) => print!("{}\t", v),
+    //         Value::Int32(v) => print!("{}\t", v),
+    //         Value::Int64(v) => print!("{}\t", v),
+    //         Value::Float(v) => print!("{}\t", v),
+    //         Value::Double(v) => print!("{}\t", v),
+    //         Value::Text(v) => print!("{}\t", v),
+    //         Value::Null => print!("null\t"),
+    //     });
+    //     print!("\n");
+    // });
+
+    let mut table = Table::new();
+    table.set_titles(Row::new(
+        dataset
+            .get_column_names()
+            .iter()
+            .map(|c| cell!(c))
+            .collect(),
+    ));
+    dataset.for_each(|r: RowRecord| {
+        table.add_row(Row::new(
+            r.values.iter().map(|v: &Value| cell!(v)).collect(),
+        ));
+    });
+    table.printstd();
 
-    let dataset = session.execute_query_statement("select * from root.ln.device2", None)?;
-    print_dataset(dataset)?;
-    // dataset.for_each(|r| println!("timestamp: {} {:?}", r.timestamp, r.values));
     // let timestamps: Vec<i64> = dataset.map(|r| r.timestamp).collect();
     // let count = dataset.count();
 
-    let ds = session.execute_statement("show timeseries", None)?;
-    print_dataset(ds)?;
+    let dataset = session.execute_statement("show timeseries", None)?;
+    let mut table = Table::new();
+    table.set_titles(Row::new(
+        dataset
+            .get_column_names()
+            .iter()
+            .map(|c| cell!(c))
+            .collect(),
+    ));
+    dataset.for_each(|r: RowRecord| {
+        table.add_row(Row::new(
+            r.values.iter().map(|v: &Value| cell!(v)).collect(),
+        ));
+    });
+    table.printstd();
 
     session.execute_batch_statement(vec![
-        "insert into root.sg1.dev6(time,s5) values(1,true)",
-        "insert into root.sg1.dev6(time,s5) values(2,true)",
-        "insert into root.sg1.dev6(time,s5) values(3,true)",
+        "insert into root.sg_rs.dev6(time,s5) values(1,true)",
+        "insert into root.sg_rs.dev6(time,s5) values(2,true)",
+        "insert into root.sg_rs.dev6(time,s5) values(3,true)",
     ])?;
 
-    let ds = session.execute_raw_data_query(
+    let dataset = session.execute_raw_data_query(
         vec![
-            "root.ln.device2.restart_count",
-            "root.ln.device2.tick_count",
-            "root.ln.device2.description",
+            "root.sg_rs.device2.restart_count",
+            "root.sg_rs.device2.tick_count",
+            "root.sg_rs.device2.description",
         ],
         0,
         i64::MAX,
     )?;
-    print_dataset(ds)?;
+    let mut table = Table::new();
+    table.set_titles(Row::new(
+        dataset
+            .get_column_names()
+            .iter()
+            .map(|c| cell!(c))
+            .collect(),
+    ));
+    dataset.for_each(|r: RowRecord| {
+        table.add_row(Row::new(
+            r.values.iter().map(|v: &Value| cell!(v)).collect(),
+        ));
+    });
+    //execute_raw_data_query
+    table.printstd();
 
-    if let Some(dataset) = session.execute_update_statement("delete timeseries root.sg1.dev1.*")? {
-        print_dataset(dataset)?;
+    if let Some(dataset) =
+        session.execute_update_statement("delete timeseries root.sg_rs.dev1.*")?
+    {
+        dataset.for_each(|r| println!("timestamp: {} {:?}", r.timestamp, r.values));
     }
 
     session.close()?;
@@ -256,7 +288,7 @@ fn run_example<T: Session>(mut session: T) -> Result<(), Box<dyn Error>> {
 
 fn create_tablet(row_count: i32, start_timestamp: i64) -> Tablet {
     let mut tablet = Tablet::new(
-        "root.ln.device2",
+        "root.sg_rs.device2",
         vec![
             MeasurementSchema::new(
                 String::from("status"),
